use clap::{Arg, ArgMatches, Command};

use crate::commands;
use crate::commands::add::AddArgs;

pub fn create() -> Command {
    Command::new("add")
        .arg(
            Arg::new("files")
            .required(true)
            .conflicts_with("all")
            .num_args(1..)
            .value_name("FILE")
            .help("Files to add"),
            )
        .arg(
            Arg::new("force")
            .short('f')
            .long("force")
            .help("Allow adding otherwise ignored files."),
            )
        .arg(
            Arg::new("all")
            .short('A')
            .long("all")
            .help("This adds, modifies, and removes index entries to match the working tree"),
            )
        .about("Add changes to the index")
}

pub fn handler(args: &ArgMatches) {
    commands::add::add(AddArgs {
        files: match args.get_many::<String>("files") {
            None => vec![],
            Some(vals) => vals.map(|s| s.to_string()).collect(),
        },
        force: args.contains_id("force"),
        all: args.contains_id("all"),
    });
}
